@@ -1123,7 +1123,7 @@ KMPrintCommand::KMPrintCommand(QWidget *parent, const KMPrintCommandInfo &comman
 
 KMCommand::Result KMPrintCommand::execute()
 {
-    KMReaderWin *printerWin = new KMReaderWin(nullptr, kmkernel->mainWin(), nullptr);
+    KMReaderWin *printerWin = new KMReaderWin(nullptr, parentWidget(), nullptr);
     printerWin->setPrinting(true);
     printerWin->readConfig();
     printerWin->setPrintElementBackground(MessageViewer::MessageViewerSettings::self()->printBackgroundColorImages());
@@ -1765,9 +1765,9 @@ KMSaveAttachmentsCommand::KMSaveAttachmentsCommand(QWidget *parent, const Akonad
     fetchScope().fetchFullPayload(true);
 }
 
-KMSaveAttachmentsCommand::KMSaveAttachmentsCommand(QWidget *parent, const Akonadi::Item::List &msgs)
+KMSaveAttachmentsCommand::KMSaveAttachmentsCommand(QWidget *parent, const Akonadi::Item::List &msgs, MessageViewer::Viewer *viewer)
     : KMCommand(parent, msgs)
-    , mViewer(nullptr)
+    , mViewer(viewer)
 {
     fetchScope().fetchFullPayload(true);
 }
